<?php

/* Adapted from code in Rookie (c) 2021, ThemeBoy. */
/* Adapted from code in Rookie Lite (c) 2018, MH Themes. */

if (!defined('ABSPATH')) {
  exit;
}

/***** Show Welcome Screen After Theme Activation *****/

if (!function_exists('lplite_welcome_admin')) {
  function lplite_welcome_admin() {
    global $pagenow;
    if (is_admin() && isset($_GET['activated']) && $pagenow == "themes.php") {
      wp_redirect('themes.php?page=lplite');
      exit;
    }
  }
}
add_action('admin_init', 'lplite_welcome_admin', 1);

/***** Theme Info Page *****/

if (!function_exists('lplite_theme_info_page')) {
  function lplite_theme_info_page() {
    add_theme_page(esc_html__('Welcome to LawPress Lite', 'lawpress-lite'), esc_html__('Theme Info', 'lawpress-lite'), 'edit_theme_options', 'lplite', 'lplite_display_theme_page');
  }
}
add_action('admin_menu', 'lplite_theme_info_page');

if (!function_exists('lplite_display_theme_page')) {
  function lplite_display_theme_page() {
    $lplite_data = wp_get_theme(); ?>
    <div class="theme-info-wrap">
      <h1>
        <?php printf(esc_html__('Welcome to %1$1s %2$2s', 'lawpress-lite'), 'LawPress Lite', $lplite_data['Version']); ?>
      </h1>
      <div class="lplite-row theme-intro lplite-clearfix">
        <div class="lplite-col-1-3">
          <img class="theme-screenshot" src="<?php echo esc_url(get_template_directory_uri()); ?>/screenshot.png" alt="<?php esc_attr_e('Theme Screenshot', 'lawpress-lite'); ?>" />
        </div>
        <div class="lplite-col-2-3 theme-description">
          <?php echo esc_html($lplite_data['Description']); ?>
        </div>
      </div>
      <hr>
      <div id="getting-started">
        <h3>
          <?php printf(esc_html__('Get Started with %s', 'lawpress-lite'), $lplite_data['Name']); ?>
        </h3>
        <div class="lplite-row lplite-clearfix">
          <div class="lplite-col-1-2">
            <div class="section">
              <h4>
                <span class="dashicons dashicons-welcome-learn-more"></span>
                <?php esc_html_e('Theme Documentation', 'lawpress-lite'); ?>
              </h4>
              <p class="about">
                <?php printf(esc_html__('Need any help with configuring %s? The documentation for this theme includes all theme related information that is needed to get your site up and running in no time. In case you have any additional questions, feel free to reach out in the theme support forums on WordPress.org.', 'lawpress-lite'), $lplite_data['Name']); ?>
              </p>
              <p>
                <a href="<?php echo esc_url('https://docs.businessupwebsite.com/docs/lawpress-lite-theme/'); ?>" target="_blank" class="button button-secondary">
                  <?php esc_html_e('Theme Documentation', 'lawpress-lite'); ?>
                </a>
                <a href="<?php echo esc_url('https://businessupwebsite.com/themes/lawpress-lite/'); ?>" target="_blank" class="button button-secondary">
                  <?php esc_html_e('Theme Info Page', 'lawpress-lite'); ?>
                </a>
              </p>
            </div>
            <div class="section">
              <h4>
                <span class="dashicons dashicons-admin-appearance"></span>
                <?php esc_html_e('Theme Options', 'lawpress-lite'); ?>
              </h4>
              <p class="about">
                <?php printf(esc_html__('%s supports the Theme Customizer for all theme settings. Click "Customize Theme" to open the Customizer now.',  'lawpress-lite'), $lplite_data['Name']); ?>
              </p>
              <p>
                <a href="<?php echo admin_url('customize.php'); ?>" class="button button-secondary">
                  <?php esc_html_e('Customize Theme', 'lawpress-lite'); ?>
                </a>
              </p>
            </div>
          </div>
          <div class="lplite-col-1-2">
            <div class="section">
              <h4>
                <span class="dashicons dashicons-cart"></span>
                <?php esc_html_e('LawPress All Add-ons', 'lawpress-lite'); ?>
              </h4>
              <p class="about">
                <?php esc_html_e('If you like LawPress Lite theme, you can unleash its full potential with LawPress Add-ons which includes advanced settings, carousel, testimonials, locations and premium support.', 'lawpress-lite'); ?>
              </p>
              <p>
                <a href="<?php echo esc_url('https://businessupwebsite.com/lawpress-all-add-ons/'); ?>" target="_blank" class="button button-primary">
                  <?php esc_html_e('Get LawPress All Add-ons', 'lawpress-lite'); ?>
                </a>
              </p>
            </div>
            <div class="section">
              <h4>
                <span class="dashicons dashicons-images-alt"></span>
                <?php esc_html_e('LawPress Lite Theme Demo', 'lawpress-lite'); ?>
              </h4>
              <p class="about">
                <?php esc_html_e('You can check how this theme looks on the demo website. There are also other available themes for the law firm website.', 'lawpress-lite'); ?>
              </p>
              <p>
                <a href="<?php echo esc_url('https://lawpress-lite-theme.businessupwebsite.com/'); ?>" target="_blank" class="button button-secondary">
                  <?php esc_html_e('Theme Demo', 'lawpress-lite'); ?>
                </a>
                <a href="<?php echo esc_url('https://businessupwebsite.com/themes/'); ?>" target="_blank" class="button button-primary">
                  <?php esc_html_e('Other Themes', 'lawpress-lite'); ?>
                </a>
              </p>
            </div>
          </div>
        </div>
      </div>
      <hr>
      <div class="theme-comparison">
        <h3 class="theme-comparison-intro">
          <?php esc_html_e('Get LawPress All Add-ons for more features:', 'lawpress-lite'); ?>
        </h3>
        <table>
          <thead class="theme-comparison-header">
            <tr>
              <th class="table-feature-title"><h3><?php esc_html_e('Features', 'lawpress-lite'); ?></h3></th>
              <th><h3><?php esc_html_e('LawPress', 'lawpress-lite'); ?></h3></th>
              <th><h3><?php esc_html_e('LawPress All Add-ons', 'lawpress-lite'); ?></h3></th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <td><h3><?php esc_html_e('Price', 'lawpress-lite'); ?></h3></td>
              <td><?php esc_html_e('Free', 'lawpress-lite'); ?></td>
              <td>
                <a href="<?php echo esc_url('https://businessupwebsite.com/lawpress-all-add-ons/'); ?>" target="_blank">
                  <?php esc_html_e('View pricing', 'lawpress-lite'); ?>
                </a>
              </td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Practice Areas Pages', 'lawpress-lite'); ?></h3></td>
              <td><span class="dashicons dashicons-yes"></span></td>
              <td><span class="dashicons dashicons-yes"></span></td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Attorneys Pages', 'lawpress-lite'); ?></h3></td>
              <td><span class="dashicons dashicons-yes"></span></td>
              <td><span class="dashicons dashicons-yes"></span></td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Cases Pages', 'lawpress-lite'); ?></h3></td>
              <td><span class="dashicons dashicons-yes"></span></td>
              <td><span class="dashicons dashicons-yes"></span></td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Law Shortcodes (Grids, Tables)', 'lawpress-lite'); ?></h3></td>
              <td><span class="dashicons dashicons-yes"></span></td>
              <td><span class="dashicons dashicons-yes"></span></td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Advanced Settings', 'lawpress-lite'); ?></h3></td>
              <td><span class="dashicons dashicons-no"></span></td>
              <td><span class="dashicons dashicons-yes"></span></td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Law Shortcodes (Carousel)', 'lawpress-lite'); ?></h3></td>
              <td><span class="dashicons dashicons-no"></span></td>
              <td><span class="dashicons dashicons-yes"></span></td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Testimonials', 'lawpress-lite'); ?></h3></td>
              <td><span class="dashicons dashicons-no"></span></td>
              <td><span class="dashicons dashicons-yes"></span></td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Locations', 'lawpress-lite'); ?></h3></td>
              <td><span class="dashicons dashicons-no"></span></td>
              <td><span class="dashicons dashicons-yes"></span></td>
            </tr>
            <tr>
              <td><h3><?php esc_html_e('Premium Support', 'lawpress-lite'); ?></h3></td>
              <td><?php esc_html_e('Support forum', 'lawpress-lite'); ?></td>
              <td><?php esc_html_e('Priority email support', 'lawpress-lite'); ?></td>
            </tr>
            <tr>
              <td></td>
              <td></td>
              <td>
                <a href="<?php echo esc_url('https://businessupwebsite.com/lawpress-all-add-ons/'); ?>" target="_blank" class="upgrade-button">
                  <?php esc_html_e('Get LawPress All Add-ons', 'lawpress-lite'); ?>
                </a>
              </td>
            </tr>
          </tbody>
        </table>
      </div>
      <hr>
      <div id="theme-author">
        <p>
          <?php printf(esc_html__('%1$1s is made for you by %2$2s. If you like %3$3s: %4$4s.', 'lawpress-lite'), $lplite_data['Name'], '<a target="_blank" href="https://businessupwebsite.com/" title="Ivan Chernyakov">Ivan Chernyakov</a>', $lplite_data['Name'], '<a target="_blank" href="https://wordpress.org/support/view/theme-reviews/lawpress-lite?filter=5" title="LawPress Lite Review">' . esc_html__('Rate this theme', 'lawpress-lite') . '</a>'); ?>
        </p>
      </div>
    </div><?php
  }
}

?>